local PuzzleMap = {}
local version = "1.0a"
local context
local puzzleMapWindow

local PuzzleData = {
	Zones = {
		"Silverwood",          --1
		"Freemarch",           --2
		"Stonefiled",          --3
		"Gloamwood",           --4
		"Scarlet Gorge",       --5
		"Scarwood",            --6
		"Droughlands",         --7
		"Moonshade Highlands", --8
		"Shimmersands",        --9
		"Iron Pine Peak",      --10
		"Stillmoor"            --11
	},
	Puzzles = {
		{1,6414,3153},
		{2,6134,6135},
		{3,4664,5008},
		{4,4538,2366},
		{5,3603,2776},
		{6,3140,4420},
		{7,8338,6202},
		{8,6459,1188},
		{9,6412,7720},
		{10,3770,2270},
		{11,1705,2310},

	}
}

-- Write Puzzle Data
local function WriteData(Data, Zones)
	local sze = table.getn(Data)
	local txt = "Puzzles:\n\n"

	for i=1, sze do
		--txt = txt .. tostring(Data[i][1])
		txt = txt .. tostring(Zones[Data[i][1]]) .. ": \n  (" .. tostring(Data[i][2]) .. ", " .. tostring(Data[i][3]) .. ")\n\n"
	end
	return txt
end


-- Addon Init
local function init()
	context = UI.CreateContext("puzzleMapContext")

	----------------
	-- Main Frame --
	puzzleMapWindow = UI.CreateFrame("RiftWindow", "puzzleMappuzzleMapWindow", context)
	puzzleMapWindow:SetVisible(false)
	puzzleMapWindow:SetWidth(900)
	puzzleMapWindow:SetHeight(600)
	puzzleMapWindow:SetTitle("Puzzle Map v" .. version)
	----------------

	----------------
	-- Map Frame  --
	local puzzleMapMapWindow = UI.CreateFrame("Mask", "puzzleMapMapWindow", puzzleMapWindow)
	puzzleMapMapWindow:SetWidth(600)
	puzzleMapMapWindow:SetHeight(480)
	puzzleMapMapWindow:SetPoint("TOPLEFT", puzzleMapWindow, "TOPLEFT", 25, 60)
	puzzleMapMapWindow:SetBackgroundColor(0,0,0,0.8)
	puzzleMapMapWindow:SetLayer(-3)
	----------------

	----------------
	-- Map Image  --
	local mapDim = {
		w = 640,
		h = 480,
		mw = 640,
		mh = 480
	}
	local mapImage = UI.CreateFrame("Texture", "puzzleMapMapImage", puzzleMapMapWindow)
	mapImage:SetTexture("PuzzleMap", "puzzle_map.jpg");
	mapImage:SetPoint("TOPLEFT", puzzleMapMapWindow, "TOPLEFT",0,0)
	mapImage:SetWidth(mapDim.w)
	mapImage:SetHeight(mapDim.h)
	mapImage:SetLayer(-2)

	function mapImage.Event:LeftDown()
		self.MouseDown = true
		mouseData = Inspect.Mouse()
		self.sx = mouseData.x - mapImage:GetLeft()
		self.sy = mouseData.y - mapImage:GetTop()
	end

	function mapImage.Event:MouseMove()
		if self.MouseDown then
			local nx, ny
			mouseData = Inspect.Mouse()
			nx = mouseData.x - self.sx
			ny = mouseData.y - self.sy
			mapImage:SetPoint("TOPLEFT", UIParent, "TOPLEFT", nx, ny)
		end
	end

	function mapImage.Event:LeftUp()
		if self.MouseDown then
			self.MouseDown = false
		end
	end

	----------------

	----------------
	-- Scale Text --
	local scaleText = UI.CreateFrame("Text", "puzzleMapText", puzzleMapWindow)
	scaleText:SetPoint("BOTTOMLEFT", puzzleMapWindow, "BOTTOMLEFT", 30, -10)
	scaleText:SetFontSize(15)
	scaleText:SetFontColor(71,71,71)
	scaleText:SetText("Scale:")
	----------------

	----------------
	-- Scale Slider --
	local scaleSlider = UI.CreateFrame("RiftSlider", "puzzleMapScaleSlider", puzzleMapWindow)
	scaleSlider:SetPoint("BOTTOMLEFT", puzzleMapWindow, "BOTTOMLEFT", 90, -20)
	scaleSlider:SetRange(0, 100)
	scaleSlider:SetWidth(400)

	function scaleSlider.Event:SliderChange()
		mapDim.w = mapDim.mw + (mapDim.mw * (scaleSlider:GetPosition() /30))
		mapDim.h = mapDim.mh + (mapDim.mh * (scaleSlider:GetPosition() /30))
		mapImage:SetWidth(mapDim.w)
		mapImage:SetHeight(mapDim.h)
	end

	function mapImage.Event:WheelForward()
		local d = 10
		local p = scaleSlider:GetPosition();
		if p > 90 then
			d = 100 - p
		end
		scaleSlider:SetPosition(scaleSlider:GetPosition() + d)
	end

	function mapImage.Event:WheelBack()
		local d = 10
		local p = scaleSlider:GetPosition();
		if p < 10 then
			d = p
		end
		scaleSlider:SetPosition(scaleSlider:GetPosition() - d)
	end
	----------------

	----------------
	--  Side List --
	puzzleList = UI.CreateFrame("Text", "puzzleList", puzzleMapWindow)
	puzzleList:SetWidth(240)
	puzzleList:SetHeight(480)
	puzzleList:SetBackgroundColor(0,0,0,0.8)
	puzzleList:SetPoint("TOPRIGHT", puzzleMapWindow, "TOPRIGHT", -25,60)
	puzzleList:SetFontSize(12.5)

	local txt = WriteData(PuzzleData.Puzzles, PuzzleData.Zones)
	puzzleList:SetText(txt)
	----------------

	----------------
	--  Movement  --
	puzzleMaplock = UI.CreateFrame("Frame", "Lock", puzzleMapWindow)
	puzzleMaplock:SetWidth(790)
	puzzleMaplock:SetHeight(50)
	puzzleMaplock:SetBackgroundColor(0.75,0.75,0.75,.01)
	puzzleMaplock:SetPoint("TOPLEFT", puzzleMapWindow, "TOPLEFT", 5,5)
	puzzleMaplock:SetVisible(true)

	function puzzleMaplock.Event:LeftDown()
		self.MouseDown = true
		mouseData = Inspect.Mouse()
		self.sx = mouseData.x - puzzleMapWindow:GetLeft()
		self.sy = mouseData.y - puzzleMapWindow:GetTop()
	end

	function puzzleMaplock.Event:MouseMove()
		if self.MouseDown then
			local nx, ny
			mouseData = Inspect.Mouse()
			nx = mouseData.x - self.sx
			ny = mouseData.y - self.sy
			puzzleMapWindow:SetPoint("TOPLEFT", UIParent, "TOPLEFT", nx, ny)
		end
	end

	function puzzleMaplock.Event:LeftUp()
		if self.MouseDown then
			self.MouseDown = false
		end
	end
	----------------

	----------------
	-- Reset Btn  --
	local resetButton = UI.CreateFrame("RiftButton", "puzzleMapResetButton", puzzleMapWindow)
	resetButton:SetText("Reset")
	resetButton:SetPoint("BOTTOMRIGHT", puzzleMapWindow, "BOTTOMRIGHT", -160, -20)

	function resetButton.Event:LeftPress()
		scaleSlider:SetPosition(0)

		mapDim.w = mapDim.mw
		mapDim.h = mapDim.mh
		mapImage:SetWidth(mapDim.w)
		mapImage:SetHeight(mapDim.h)

		mapImage:SetPoint("TOPLEFT", puzzleMapMapWindow, "TOPLEFT",0,0)

	end
	----------------

	----------------
	-- Close Btn  --
	local closeButton = UI.CreateFrame("RiftButton", "puzzleMapCloseButton", puzzleMapWindow)
	closeButton:SetText("Close")
	closeButton:SetPoint("BOTTOMRIGHT", puzzleMapWindow, "BOTTOMRIGHT", -20, -20)

	function closeButton.Event:LeftPress()
		puzzleMapWindow:SetVisible(false)
	end
	----------------
end

-- display
local function showpuzzleMap()
	puzzleMapWindow:SetVisible(true)
end

-- Register the slash commands
table.insert(Command.Slash.Register("pm"), {showpuzzleMap, "PuzzleMap", "Slash command"})
print("v" .. version .. " . Type /pm to show the Puzzle Map")


-- initialisation
init()